.. crimsonslate-portfolio documentation master file, created by
   sphinx-quickstart on Sun Dec  8 17:28:53 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

crimsonslate-portfolio documentation
====================================

.. toctree::
    :maxdepth: 2
    :caption: Contents

    models/index.rst
    templatetags/index.rst
    views/index.rst
